==> jc-1.4.0.tar.gz: gnu/java/net/protocol/ftp/StreamOutputStream.h <==
// class gnu.java.net.protocol.ftp.StreamOutputStream

// class file dependencies
// @dep_class 8f86c2f0d8bbeb13 gnu_java_net_protocol_ftp_DTPOutputStream
// @dep_class 8e818e501a1f934f gnu_java_net_protocol_ftp_StreamOutputStream
// @dep_class fddb41323d9c4cee java_io_FilterOutputStream
// @dep_class 4026d3144d6654d8 java_io_OutputStream
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header gnu_java_net_protocol_ftp_DTPOutputStream

#include "gnu/java/net/protocol/ftp/DTPOutputStream.h"

#ifndef _JC_gnu_java_net_protocol_ftp_StreamOutputStream_H_
#define _JC_gnu_java_net_protocol_ftp_StreamOutputStream_H_

// Forward structure declarations
struct _jc_gnu_java_net_protocol_ftp_DTP$object;
struct _jc_java_io_OutputStream$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_gnu_java_net_protocol_ftp_StreamOutputStream$sub_refs	_jc_gnu_java_net_protocol_ftp_StreamOutputStream$sub_refs;
typedef struct _jc_gnu_java_net_protocol_ftp_StreamOutputStream$sub_nonrefs	_jc_gnu_java_net_protocol_ftp_StreamOutputStream$sub_nonrefs;
typedef struct _jc_gnu_java_net_protocol_ftp_StreamOutputStream$refs	_jc_gnu_java_net_protocol_ftp_StreamOutputStream$refs;
typedef struct _jc_gnu_java_net_protocol_ftp_StreamOutputStream$nonrefs	_jc_gnu_java_net_protocol_ftp_StreamOutputStream$nonrefs;
typedef struct _jc_gnu_java_net_protocol_ftp_StreamOutputStream$object	_jc_gnu_java_net_protocol_ftp_StreamOutputStream$object;

typedef const struct _jc_gnu_java_net_protocol_ftp_StreamOutputStream$vmethods	_jc_gnu_java_net_protocol_ftp_StreamOutputStream$vmethods;
typedef const struct _jc_gnu_java_net_protocol_ftp_StreamOutputStream$vtable	_jc_gnu_java_net_protocol_ftp_StreamOutputStream$vtable;
typedef const struct _jc_gnu_java_net_protocol_ftp_StreamOutputStream$vtype	_jc_gnu_java_net_protocol_ftp_StreamOutputStream$vtype;

// Constructors
extern void _jc_gnu_java_net_protocol_ftp_StreamOutputStream$method$_init$6e5b27297a1ccb9b(_jc_env *, struct _jc_gnu_java_net_protocol_ftp_StreamOutputStream$object *, struct _jc_object *, struct _jc_java_io_OutputStream$object *);

// Virtual methods
extern void _jc_gnu_java_net_protocol_ftp_StreamOutputStream$method$write$6377ac6964854eb2(_jc_env *, struct _jc_gnu_java_net_protocol_ftp_StreamOutputStream$object *, jint);
extern void _jc_gnu_java_net_protocol_ftp_StreamOutputStream$method$write$18e189e8fc25f121(_jc_env *, struct _jc_gnu_java_net_protocol_ftp_StreamOutputStream$object *, struct _jc_byte_array *);
extern void _jc_gnu_java_net_protocol_ftp_StreamOutputStream$method$write$306a698343ec27e8(_jc_env *, struct _jc_gnu_java_net_protocol_ftp_StreamOutputStream$object *, struct _jc_byte_array *, jint, jint);

// Virtual method descriptors
extern _jc_method _jc_gnu_java_net_protocol_ftp_StreamOutputStream$method_info$write$6377ac6964854eb2;
extern _jc_method _jc_gnu_java_net_protocol_ftp_StreamOutputStream$method_info$write$18e189e8fc25f121;
extern _jc_method _jc_gnu_java_net_protocol_ftp_StreamOutputStream$method_info$write$306a698343ec27e8;

// Virtual methods structure
struct _jc_gnu_java_net_protocol_ftp_StreamOutputStream$vmethods {
	void	(*write$6377ac6964854eb2)(_jc_env *, struct _jc_gnu_java_net_protocol_ftp_StreamOutputStream$object *, jint);
	void	(*write$18e189e8fc25f121)(_jc_env *, struct _jc_gnu_java_net_protocol_ftp_StreamOutputStream$object *, struct _jc_byte_array *);
	void	(*write$306a698343ec27e8)(_jc_env *, struct _jc_gnu_java_net_protocol_ftp_StreamOutputStream$object *, struct _jc_byte_array *, jint, jint);
};

// Vtable
struct _jc_gnu_java_net_protocol_ftp_StreamOutputStream$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_io_OutputStream$vmethods	java_io_OutputStream;
	_jc_java_io_FilterOutputStream$vmethods	java_io_FilterOutputStream;
	_jc_gnu_java_net_protocol_ftp_DTPOutputStream$vmethods	gnu_java_net_protocol_ftp_DTPOutputStream;
	_jc_gnu_java_net_protocol_ftp_StreamOutputStream$vmethods	gnu_java_net_protocol_ftp_StreamOutputStream;
};

// Vtype
struct _jc_gnu_java_net_protocol_ftp_StreamOutputStream$vtype {
	_jc_type			type;
	_jc_gnu_java_net_protocol_ftp_StreamOutputStream$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_net_protocol_ftp_StreamOutputStream$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_net_protocol_ftp_StreamOutputStream$refs {
    _jc_gnu_java_net_protocol_ftp_StreamOutputStream$sub_refs	gnu_java_net_protocol_ftp_StreamOutputStream;
    _jc_gnu_java_net_protocol_ftp_DTPOutputStream$sub_refs	gnu_java_net_protocol_ftp_DTPOutputStream;
    _jc_java_io_FilterOutputStream$sub_refs	java_io_FilterOutputStream;
    _jc_java_io_OutputStream$sub_refs	java_io_OutputStream;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_net_protocol_ftp_StreamOutputStream$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_net_protocol_ftp_StreamOutputStream$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_io_OutputStream$sub_nonrefs	java_io_OutputStream;
    _jc_java_io_FilterOutputStream$sub_nonrefs	java_io_FilterOutputStream;
    _jc_gnu_java_net_protocol_ftp_DTPOutputStream$sub_nonrefs	gnu_java_net_protocol_ftp_DTPOutputStream;
    _jc_gnu_java_net_protocol_ftp_StreamOutputStream$sub_nonrefs	gnu_java_net_protocol_ftp_StreamOutputStream;
};

// Object instance structure
struct _jc_gnu_java_net_protocol_ftp_StreamOutputStream$object {
	_jc_gnu_java_net_protocol_ftp_StreamOutputStream$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_net_protocol_ftp_StreamOutputStream$vtype	*vtype;
	_jc_gnu_java_net_protocol_ftp_StreamOutputStream$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_net_protocol_ftp_StreamOutputStream$vtype _jc_gnu_java_net_protocol_ftp_StreamOutputStream$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_net_protocol_ftp_StreamOutputStream, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_net_protocol_ftp_StreamOutputStream$class_object;

#endif	/* _JC_gnu_java_net_protocol_ftp_StreamOutputStream_H_ */

==> jc-1.4.6.tar.gz: gnu/java/net/protocol/ftp/StreamOutputStream.h <==
// class gnu.java.net.protocol.ftp.StreamOutputStream

// class file dependencies
// @dep_class 8f86c2f0d8bbeb13 gnu_java_net_protocol_ftp_DTPOutputStream
// @dep_class 8e818e501a1f934f gnu_java_net_protocol_ftp_StreamOutputStream
// @dep_class fddb41323d9c4cee java_io_FilterOutputStream
// @dep_class 4026d3144d6654d8 java_io_OutputStream
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header gnu_java_net_protocol_ftp_DTPOutputStream

#include "gnu/java/net/protocol/ftp/DTPOutputStream.h"

#ifndef _JC_gnu_java_net_protocol_ftp_StreamOutputStream_H_
#define _JC_gnu_java_net_protocol_ftp_StreamOutputStream_H_

// Forward structure declarations
struct _jc_gnu_java_net_protocol_ftp_DTP$object;
struct _jc_java_io_OutputStream$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_gnu_java_net_protocol_ftp_StreamOutputStream$sub_refs	_jc_gnu_java_net_protocol_ftp_StreamOutputStream$sub_refs;
typedef struct _jc_gnu_java_net_protocol_ftp_StreamOutputStream$sub_nonrefs	_jc_gnu_java_net_protocol_ftp_StreamOutputStream$sub_nonrefs;
typedef struct _jc_gnu_java_net_protocol_ftp_StreamOutputStream$refs	_jc_gnu_java_net_protocol_ftp_StreamOutputStream$refs;
typedef struct _jc_gnu_java_net_protocol_ftp_StreamOutputStream$nonrefs	_jc_gnu_java_net_protocol_ftp_StreamOutputStream$nonrefs;
typedef struct _jc_gnu_java_net_protocol_ftp_StreamOutputStream$object	_jc_gnu_java_net_protocol_ftp_StreamOutputStream$object;

typedef const struct _jc_gnu_java_net_protocol_ftp_StreamOutputStream$vmethods	_jc_gnu_java_net_protocol_ftp_StreamOutputStream$vmethods;
typedef const struct _jc_gnu_java_net_protocol_ftp_StreamOutputStream$vtable	_jc_gnu_java_net_protocol_ftp_StreamOutputStream$vtable;
typedef const struct _jc_gnu_java_net_protocol_ftp_StreamOutputStream$vtype	_jc_gnu_java_net_protocol_ftp_StreamOutputStream$vtype;

// Constructors
extern void _jc_gnu_java_net_protocol_ftp_StreamOutputStream$method$_init$6e5b27297a1ccb9b(_jc_env *, struct _jc_gnu_java_net_protocol_ftp_StreamOutputStream$object *, struct _jc_object *, struct _jc_java_io_OutputStream$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_gnu_java_net_protocol_ftp_StreamOutputStream$method$write$6377ac6964854eb2(_jc_env *, struct _jc_gnu_java_net_protocol_ftp_StreamOutputStream$object *, jint) _JC_JCNI_ATTR;
extern void _jc_gnu_java_net_protocol_ftp_StreamOutputStream$method$write$18e189e8fc25f121(_jc_env *, struct _jc_gnu_java_net_protocol_ftp_StreamOutputStream$object *, struct _jc_byte_array *) _JC_JCNI_ATTR;
extern void _jc_gnu_java_net_protocol_ftp_StreamOutputStream$method$write$306a698343ec27e8(_jc_env *, struct _jc_gnu_java_net_protocol_ftp_StreamOutputStream$object *, struct _jc_byte_array *, jint, jint) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_java_net_protocol_ftp_StreamOutputStream$method_info$write$6377ac6964854eb2;
extern _jc_method _jc_gnu_java_net_protocol_ftp_StreamOutputStream$method_info$write$18e189e8fc25f121;
extern _jc_method _jc_gnu_java_net_protocol_ftp_StreamOutputStream$method_info$write$306a698343ec27e8;

// Virtual methods structure
struct _jc_gnu_java_net_protocol_ftp_StreamOutputStream$vmethods {
	void	(*write$6377ac6964854eb2)(_jc_env *, struct _jc_gnu_java_net_protocol_ftp_StreamOutputStream$object *, jint) _JC_JCNI_ATTR;
	void	(*write$18e189e8fc25f121)(_jc_env *, struct _jc_gnu_java_net_protocol_ftp_StreamOutputStream$object *, struct _jc_byte_array *) _JC_JCNI_ATTR;
	void	(*write$306a698343ec27e8)(_jc_env *, struct _jc_gnu_java_net_protocol_ftp_StreamOutputStream$object *, struct _jc_byte_array *, jint, jint) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_java_net_protocol_ftp_StreamOutputStream$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_io_OutputStream$vmethods	java_io_OutputStream;
	_jc_java_io_FilterOutputStream$vmethods	java_io_FilterOutputStream;
	_jc_gnu_java_net_protocol_ftp_DTPOutputStream$vmethods	gnu_java_net_protocol_ftp_DTPOutputStream;
	_jc_gnu_java_net_protocol_ftp_StreamOutputStream$vmethods	gnu_java_net_protocol_ftp_StreamOutputStream;
};

// Vtype
struct _jc_gnu_java_net_protocol_ftp_StreamOutputStream$vtype {
	_jc_type			type;
	_jc_gnu_java_net_protocol_ftp_StreamOutputStream$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_net_protocol_ftp_StreamOutputStream$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_net_protocol_ftp_StreamOutputStream$refs {
    _jc_gnu_java_net_protocol_ftp_StreamOutputStream$sub_refs	gnu_java_net_protocol_ftp_StreamOutputStream;
    _jc_gnu_java_net_protocol_ftp_DTPOutputStream$sub_refs	gnu_java_net_protocol_ftp_DTPOutputStream;
    _jc_java_io_FilterOutputStream$sub_refs	java_io_FilterOutputStream;
    _jc_java_io_OutputStream$sub_refs	java_io_OutputStream;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_net_protocol_ftp_StreamOutputStream$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_net_protocol_ftp_StreamOutputStream$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_io_OutputStream$sub_nonrefs	java_io_OutputStream;
    _jc_java_io_FilterOutputStream$sub_nonrefs	java_io_FilterOutputStream;
    _jc_gnu_java_net_protocol_ftp_DTPOutputStream$sub_nonrefs	gnu_java_net_protocol_ftp_DTPOutputStream;
    _jc_gnu_java_net_protocol_ftp_StreamOutputStream$sub_nonrefs	gnu_java_net_protocol_ftp_StreamOutputStream;
};

// Object instance structure
struct _jc_gnu_java_net_protocol_ftp_StreamOutputStream$object {
	_jc_gnu_java_net_protocol_ftp_StreamOutputStream$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_net_protocol_ftp_StreamOutputStream$vtype	*vtype;
	_jc_gnu_java_net_protocol_ftp_StreamOutputStream$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_net_protocol_ftp_StreamOutputStream$vtype _jc_gnu_java_net_protocol_ftp_StreamOutputStream$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_net_protocol_ftp_StreamOutputStream, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_net_protocol_ftp_StreamOutputStream$class_object;

#endif	/* _JC_gnu_java_net_protocol_ftp_StreamOutputStream_H_ */
